package envoy.client.net;

import java.util.List;
import java.util.function.Consumer;
import java.util.logging.Logger;

import envoy.client.util.EnvoyLog;
import envoy.data.User;
import envoy.event.EventBus;
import envoy.event.UserStatusChangeEvent;

/**
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>UserStatusChangeProcessor.java</strong><br>
 * Created: <strong>2 Feb 2020</strong><br>
 *
 * @author Leon Hofmeister
 * @since Envoy v0.3-alpha
 */
public class UserStatusChangeProcessor implements Consumer<UserStatusChangeEvent> {

	private static final Logger	logger	= EnvoyLog.getLogger(UserStatusChangeProcessor.class.getSimpleName());
	private Client				client;

	/**
	 * @param client the {@link Client} who receives an
	 *               {@link UserStatusChangeEvent}
	 * @since Envoy v0.3-alpha
	 */
	public UserStatusChangeProcessor(Client client) { this.client = client; }

	@Override
	public void accept(UserStatusChangeEvent evt) {
		logger.info("Received " + evt);
		List<User> contacts = client.getContacts().getContacts();
		contacts.stream().filter((user) -> user.getId() == evt.getId()).findFirst().get().setStatus(evt.get());
		EventBus.getInstance().dispatch(evt);
	}

}
